@@ -82,6 +82,9 @@ class App(object):
         """加载当前app_dir文件夹下的所有app（递归）, 入口函数都是main
         1. 过滤掉 _ 开头的py文件
         2. 支持单文件
+        todo: prefix bug????
+
+        appcli easy-run app_dir
         """
 
         app_home = Path(sys_path_append(app_dir))
@@ -94,7 +97,7 @@ class App(object):
             if not p.stem.startswith('_'):  # 过滤_开头的py
                 home_parts = p.parts[n:]
                 route = '/' + "/".join(home_parts)[:-3]
-                route = str(Path(prefix) / Path(route))
+                route = 'xx'# str(Path(prefix) / Path(route))
                 routes.append(route)
 
                 func = importlib.import_module('.'.join(home_parts)[:-3]).main
